document.addEventListener('DOMContentLoaded', function () {
    // Pesquisa de canais
    const searchInput = document.getElementById('searchInput');
    searchInput.addEventListener('input', function () {
        const searchTerm = this.value.toLowerCase();
        document.querySelectorAll('.channel-card').forEach(card => {
            const channelName = card.dataset.name.toLowerCase();
            card.style.display = channelName.includes(searchTerm) ? 'block' : 'none';
        });
    });

    // Loading state
    window.addEventListener('beforeunload', function () {
        document.getElementById('loading').style.display = 'block';
    });

    window.addEventListener('load', function () {
        document.getElementById('loading').style.display = 'none';
    });
});

function copyStreamUrl(id, lat, long) {
    const quality = new URLSearchParams(window.location.search).get('quality') || 'HD';
    const baseUrl = window.location.protocol + '//' + window.location.host;
    const fullUrl = baseUrl + `/globoplay/globo.php?id=${id}&lat=${lat}&long=${long}&quality=${quality}`;

    navigator.clipboard.writeText(fullUrl).then(() => {
        showNotification('URL copiada!');
    }).catch(err => {
        // Fallback para navegadores que não suportam clipboard API
        const tempInput = document.createElement('input');
        tempInput.value = fullUrl;
        document.body.appendChild(tempInput);
        tempInput.select();
        document.execCommand('copy');
        document.body.removeChild(tempInput);
        showNotification('URL copiada!');
    });
}

function getDrmKey(id, lat, long) {
    const quality = new URLSearchParams(window.location.search).get('quality') || 'HD';
    const baseUrl = window.location.protocol + '//' + window.location.host;
    const url = baseUrl + `/globoplay/globo.php?id=${id}&lat=${lat}&long=${long}&quality=${quality}&drm=yes`;

    document.getElementById('loading').style.display = 'block';

    fetch(url)
        .then(response => response.text())
        .then(key => {
            const keyDisplay = document.getElementById(`key-${id}`);
            keyDisplay.textContent = key;
            showNotification('Chave DRM gerada!');
        })
        .catch(error => {
            showNotification('Erro ao gerar chave DRM', true);
        })
        .finally(() => {
            document.getElementById('loading').style.display = 'none';
        });
}

function previewStream(id, lat, long) {
    const quality = new URLSearchParams(window.location.search).get('quality') || 'HD';
    const baseUrl = window.location.protocol + '//' + window.location.host;
    const url = baseUrl + `/globoplay/globo.php?id=${id}&lat=${lat}&long=${long}&quality=${quality}`;
    window.open(url, '_blank');
}

function showNotification(message, isError = false) {
    const notification = document.createElement('div');
    notification.textContent = message;
    notification.style.position = 'fixed';
    notification.style.top = '10px';
    notification.style.left = '50%';
    notification.style.transform = 'translateX(-50%)';
    notification.style.backgroundColor = isError ? '#dc3545' : '#28a745';
    notification.style.color = '#fff';
    notification.style.padding = '10px 20px';
    notification.style.borderRadius = '5px';
    notification.style.zIndex = '9999';

    document.body.appendChild(notification);

    setTimeout(() => {
        document.body.removeChild(notification);
    }, 3000);
}