<?php
require_once 'classes/GloboManager.php';
$channels = json_decode(file_get_contents('data/channels.json'), true);
?>
<!DOCTYPE html>
<html lang="pt-br">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Globoplay Stream Manager</title>
   

    <style>
        body {
            background-color: #f0f2f5;
            padding: 20px;
        }
        
        .header {
            background-color: #fff;
            padding: 20px;
            border-radius: 8px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .search-container {
            margin-bottom: 20px;
        }

        #searchInput {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 5px;
            font-size: 16px;
        }

        .channels-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 20px;
        }

        .channel-card {
            background: white;
            border-radius: 8px;
            padding: 15px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .channel-card img {
            width: 100%;
            height: 150px;
            object-fit: contain;
            border-radius: 4px;
            margin-bottom: 10px;
        }

        .channel-info {
            background: #f8f9fa;
            padding: 10px;
            border-radius: 5px;
            margin: 10px 0;
        }

        .info-badge {
            display: inline-block;
            background: #e9ecef;
            padding: 3px 8px;
            border-radius: 3px;
            margin: 2px;
            font-size: 0.9em;
            color: #666;
        }

        .button-group {
            display: flex;
            gap: 8px;
            margin-top: 10px;
        }

        .button-group button {
            flex: 1;
            padding: 8px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            color: white;
            transition: opacity 0.2s;
        }

        .btn-copy {
            background-color: #007bff;
        }

        .btn-preview {
            background-color: #17a2b8;
        }

        .btn-drm {
            background-color: #ffc107;
            color: black !important;
        }

        .key-display {
            margin-top: 10px;
            font-family: monospace;
            word-break: break-all;
            padding: 5px;
            background: #f8f9fa;
            border-radius: 4px;
        }


       
        .modal-header h3 {
    font-size: 1.2rem; /* Reduzido */
    margin: 0;
    color: white;
}


.btn.active {
    background-color: #007bff;
    color: white; /* Cor do texto */
    border: 1px solid #007bff; 
}

.btn-primary, .btn-secondary {
    padding: 10px 15px;
    text-decoration: none;
    margin: 0 5px;
    border-radius: 5px;
    display: inline-block;
    background-color: #6c757d;
    color: white;
}

.btn-secondary {
    background-color: #6c757d;
}



.header {
    display: flow-root;
}

.quality-selector {
    float: right;
}
    </style>
</head>
<body>
    <div class="container">
		  <div class="header">
		<h1>Globoplay Script V4.7</h1>
		<div class="quality-selector">
			<a href="?quality=HD" class="btn btn-primary" id="btn-hd">HD</a>
			<a href="?quality=SD" class="btn btn-secondary" id="btn-sd">SD</a>
		</div>
	</div>


        <div class="search-container">
            <input type="text" id="searchInput" placeholder="Pesquisar canais...">
        </div>

        <div class="channels-grid">
            <?php foreach ($channels as $channel): ?>
                <div class="channel-card" data-name="<?= htmlspecialchars($channel['nome']) ?>">
                    <img src="https://s04.video.glbimg.com/x720/<?= $channel['id'] ?>.jpg" 
                         alt="<?= htmlspecialchars($channel['nome']) ?>">
                    
                    <h3><?= htmlspecialchars($channel['nome']) ?></h3>
                    
                    <div class="channel-info">
                        <div class="info-badge">ID: <?= $channel['id'] ?></div>
                        <div class="info-badge">Região: <?= $channel['lat'] ?>, <?= $channel['long'] ?></div>
                        <div class="info-badge">DRM: <?= $channel['drm'] ?></div>
                    </div>

                    <div class="button-group">
                        <button onclick="copyStreamUrl('<?= $channel['id'] ?>', '<?= $channel['lat'] ?>', '<?= $channel['long'] ?>')" 
                                class="btn-copy">
                            Copiar URL
                        </button>
                        
                      <button onclick="handleStream('<?= $channel['id'] ?>', '<?= $channel['lat'] ?>', '<?= $channel['long'] ?>')" 
						class="btn-preview">
					Preview
				</button>

										
                        <?php if ($channel['drm'] === 'yes'): ?>
                            <button onclick="getDrmKey('<?= $channel['id'] ?>', '<?= $channel['lat'] ?>', '<?= $channel['long'] ?>')" 
                                    class="btn-drm">
                                Gerar Key
                            </button>
                        <?php endif; ?>
                    </div>

                    <?php if ($channel['drm'] === 'yes'): ?>
                        <div id="key-<?= $channel['id'] ?>" class="key-display"></div>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        </div>
    </div>


<!-- Modal -->
<div id="modalPlayer" class="modal" style="display: none;">
    <div class="modal-content">
        <span class="close" onclick="closeModal()">&times;</span>
        <iframe id="playerFrame" src="" frameborder="0" allowfullscreen></iframe>
    </div>
</div>

<style>
.modal {
    display: none;
    position: fixed;
    z-index: 1000;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    background-color: rgba(0, 0, 0, 0.8);
    justify-content: center;
    align-items: center;
}
.modal-content {
    position: relative;
    width: 80%;
    height: 80%;
    background: #000;
}
.close {
    position: absolute;
    top: 10px;
    right: 15px;
    font-size: 28px;
    color: white;
    cursor: pointer;
    background: rgba(0, 0, 0, 0.5);
    padding: 5px 10px;
    border-radius: 5px;
    transition: background 0.3s, transform 0.2s;
}

.close:hover {
    background: rgba(255, 0, 0, 0.7);
    transform: scale(1.1);
}

iframe {
    width: 100%;
    height: 100%;
}


</style>




    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        // Busca de canais
        document.getElementById('searchInput').addEventListener('input', function() {
            const searchTerm = this.value.toLowerCase();
            document.querySelectorAll('.channel-card').forEach(card => {
                const channelName = card.dataset.name.toLowerCase();
                card.style.display = channelName.includes(searchTerm) ? 'block' : 'none';
            });
        });



// copiar url
      function copyStreamUrl(id, lat, long) {
    const quality = new URLSearchParams(window.location.search).get('quality') || 'HD';
    const baseUrl = window.location.protocol + '//' + window.location.host;
    const fullUrl = `${baseUrl}/globoplay/redirect.php?id=${id}&lat=${lat}&long=${long}&quality=${quality}`;



    if (navigator.clipboard && navigator.clipboard.writeText) {
        navigator.clipboard.writeText(fullUrl).then(() => {
            showNotification('URL copiada!');
        }).catch(err => {
            fallbackCopy(fullUrl);
        });
    } else {
        fallbackCopy(fullUrl);
    }
}

function fallbackCopy(text) {
    const tempInput = document.createElement('input');
    tempInput.value = text;
    document.body.appendChild(tempInput);
    tempInput.select();
    document.execCommand('copy');
    document.body.removeChild(tempInput);
    showNotification('URL copiada!');
}

        function getDrmKey(id, lat, long) {
            const quality = new URLSearchParams(window.location.search).get('quality') || 'HD';
            const baseUrl = window.location.protocol + '//' + window.location.host;
            const url = baseUrl + `/globoplay/globo_keys.php?id=${id}&lat=${lat}&long=${long}&quality=${quality}&drm=yes`;
            
            fetch(url)
                .then(response => response.text())
                .then(key => {
                    const keyDisplay = document.getElementById(`key-${id}`);
                    keyDisplay.textContent = key;
                    showNotification('Chave DRM gerada!');
                })
                .catch(error => {
                    showNotification('Erro ao gerar chave DRM', true);
                });
        }

        function showNotification(message, isError = false) {
            const notification = document.createElement('div');
            notification.textContent = message;
            notification.style.position = 'fixed';
            notification.style.top = '10px';
            notification.style.left = '50%';
            notification.style.transform = 'translateX(-50%)';
            notification.style.backgroundColor = isError ? '#d90015' : '#000000';
            notification.style.color = '#fff';
            notification.style.padding = '10px 20px';
            notification.style.borderRadius = '5px';
            notification.style.zIndex = '9999';
            
            document.body.appendChild(notification);
            
            setTimeout(() => {
                document.body.removeChild(notification);
            }, 3000);
        }

function handleStream(id, lat, long) {

			const quality = new URLSearchParams(window.location.search).get('quality') || 'HD';
            const baseUrl = window.location.protocol + '//' + window.location.host;
            const url = baseUrl + `/globoplay/player.php?id=${id}&lat=${lat}&long=${long}&quality=${quality}`;

            // Abrir o modal e carregar o player
            document.getElementById('playerFrame').src = url;
            document.getElementById('modalPlayer').style.display = "flex";
  

}

function closeModal() {
    document.getElementById('modalPlayer').style.display = "none";
    document.getElementById('playerFrame').src = ""; // Limpar o iframe ao fechar
}

	 window.addEventListener('DOMContentLoaded', () => {
        // Verificar qual parâmetro 'quality' está na URL
        const quality = new URLSearchParams(window.location.search).get('quality');
        
        // Selecionar os botões
        const btnHD = document.getElementById('btn-hd');
        const btnSD = document.getElementById('btn-sd');
        
        // Remover a classe 'active' dos dois botões
        btnHD.classList.remove('active');
        btnSD.classList.remove('active');
        
        // Adicionar a classe 'active' ao botão selecionado com base no parâmetro da URL
        if (quality === 'HD') {
            btnHD.classList.add('active');
        } else if (quality === 'SD') {
            btnSD.classList.add('active');
        }
    });

    </script>
	
</body>
</html>