<?php
if (isset($_GET['stream'])) {
    $serverIp = getHostByName(getHostName()); // Obtém o IP da máquina automaticamente
    $baseUrl = "http://$serverIp/globoplay/redirect.php"; // Usa o IP dinâmico
    $fullUrl = $baseUrl . "?" . $_SERVER['QUERY_STRING']; 
    
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $fullUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HEADER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, false);
    
    $response = curl_exec($ch);
    curl_close($ch);
    
    if (preg_match('/Location: (.*?)\r\n/', $response, $matches)) {
        $streamUrl = trim($matches[1]);
        echo $streamUrl;
    }
    exit;
}

if (isset($_GET['proxy'])) {
    $url = base64_decode($_GET['proxy']);
    
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Origin: https://www.globo.com',
        'Referer: https://www.globo.com/',
        'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36'
    ]);
    
    $response = curl_exec($ch);
    $contentType = curl_getinfo($ch, CURLINFO_CONTENT_TYPE);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    // Se for m3u8, processa as URLs
    if (strpos($contentType, 'm3u8') !== false || strpos($url, '.m3u8') !== false) {
        // Pega o diretório base da URL
        $baseUrl = dirname($url);
        
        // Processa cada linha do m3u8
        $lines = explode("\n", $response);
        $newLines = [];
        
        foreach ($lines as $line) {
            $line = trim($line);
            // Se a linha parece uma URL
            if (preg_match('/^https?:\/\//', $line)) {
                // URL absoluta
                $newLines[] = 'player.php?proxy=' . base64_encode($line);
            } elseif (preg_match('/^\//', $line)) {
                // URL começando com /
                $newLines[] = 'player.php?proxy=' . base64_encode('https://www.globo.com' . $line);
            } elseif (preg_match('/\.(m3u8|ts)$/', $line)) {
                // URL relativa para m3u8 ou ts
                $newLines[] = 'player.php?proxy=' . base64_encode($baseUrl . '/' . $line);
            } else {
                $newLines[] = $line;
            }
        }
        $response = implode("\n", $newLines);
        $contentType = 'application/vnd.apple.mpegurl';
    }
    
    header("Access-Control-Allow-Origin: *");
    header("Content-Type: $contentType");
    echo $response;
    exit;
}
?>
<!DOCTYPE html>
<html lang="pt">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Player HLS</title>
    <script src="https://cdn.jsdelivr.net/npm/hls.js@latest"></script>
    <style>
        body { margin: 0; padding: 0; background: #000; text-align: center; }
        #video { width: 100vw; height: 100vh; background: #000; }
        #unmute-btn {
            position: absolute; bottom: 20px; left: 50%;
            transform: translateX(-50%);
            padding: 10px 20px; font-size: 16px;
            background: red; color: white; border: none; cursor: pointer;
            display: none; /* Inicialmente oculto */
        }
		
		html {
			overflow: hidden;
		}
    </style>
</head>
<body>
    <video id="video" controls autoplay muted playsinline webkit-playsinline></video>
    <button id="unmute-btn">Ativar Som 🔊</button>

    <script>
    function initPlayer() {
        const video = document.getElementById("video");
        const unmuteBtn = document.getElementById("unmute-btn");
        const url = window.location.search;

        function forcePlay() {
            video.play().catch(() => {
                console.log("Autoplay bloqueado, aguardando interação...");
                unmuteBtn.style.display = "block"; // Mostra o botão para ativar som
            });
        }

        // Inicia a tentativa de autoplay
        video.addEventListener("canplay", forcePlay);
        video.addEventListener("pause", forcePlay);

        // Ativa o som quando o usuário clicar
        unmuteBtn.addEventListener("click", () => {
            video.muted = false;
            video.play();
            unmuteBtn.style.display = "none"; // Oculta o botão após ativação
        });

        // Obtém a URL do stream
        fetch("player.php?stream=1&" + url.substring(1))
            .then(response => response.text())
            .then(streamUrl => {
                const proxyUrl = "player.php?proxy=" + btoa(streamUrl);
                if (Hls.isSupported()) {
                    const hls = new Hls({
                        enableWorker: true,
                        lowLatencyMode: true,
                        backBufferLength: 90
                    });

                    hls.loadSource(proxyUrl);
                    hls.attachMedia(video);

                    hls.on(Hls.Events.MANIFEST_PARSED, forcePlay);
                    hls.on(Hls.Events.ERROR, function(event, data) {
                        if (data.fatal) {
                            switch (data.type) {
                                case Hls.ErrorTypes.NETWORK_ERROR:
                                    console.log("Erro de rede, tentando novamente...");
                                    hls.startLoad();
                                    break;
                                case Hls.ErrorTypes.MEDIA_ERROR:
                                    console.log("Erro de mídia, tentando recuperar...");
                                    hls.recoverMediaError();
                                    break;
                            }
                        }
                    });

                    setInterval(() => {
                        if (video.paused) {
                            forcePlay();
                        }
                    }, 5000);
                }
            });
    }

    if (document.readyState === "loading") {
        document.addEventListener("DOMContentLoaded", initPlayer);
    } else {
        initPlayer();
    }
    </script>
</body>
</html>
