<?php
declare(strict_types=1);

class VideoSessionManager {
    private $urlSession;
    private $authorization;
    private $vsid;
    private $defaultHeaders;
    private $qualityMap = [
        'HD' => 'max',
        'SD' => 'low'
    ];

    public function __construct() {
        $this->urlSession = 'https://playback2.video.globo.com/v4/video-session';
        $this->authorization = 'Bearer 1173a7a200a4d8a83c5c1a3f0f3f4ba1d6f496672723231687669396a436667645735766b697a496943756a33574f614d4869744c65316b3875774c543668633347586f763935474c52456b5a58726362305753306a626655374361446e4f39737872555177673d3d3a303a7571703761756d686378317463326b7169686f75';
        $this->vsid = '47e5ac52-457b-43bc-a9c8-b2f62c7c18c8';
        
        $this->defaultHeaders = [
            'Content-Type: application/json; charset=UTF-8',
            'Authorization: ' . $this->authorization,
            'Origin: https://globoplay.globo.com',
            'Referer: https://globoplay.globo.com/'
        ];
    }

    private function makeCurlRequest(array $postData): array {
        $ch = curl_init($this->urlSession);
        
        if ($ch === false) {
            throw new RuntimeException('Falha ao inicializar CURL');
        }

        curl_setopt_array($ch, [
            CURLOPT_CUSTOMREQUEST => 'POST',
            CURLOPT_POSTFIELDS => json_encode($postData),
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_HTTPHEADER => $this->defaultHeaders,
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_SSL_VERIFYHOST => false,
            CURLOPT_TIMEOUT => 30
        ]);
        
        $result = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        
        if ($result === false) {
            $error = curl_error($ch);
            curl_close($ch);
            throw new RuntimeException("Erro na requisição CURL: $error");
        }

        curl_close($ch);

        if ($httpCode !== 200) {
            throw new RuntimeException("Erro na resposta do servidor: HTTP $httpCode");
        }

        $decodedResult = json_decode($result, true);
        
        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new RuntimeException('Erro ao decodificar resposta JSON');
        }

        return $decodedResult;
    }

    private function getVideoUrl(array $response): string {
        if (!isset($response['sources']) || !is_array($response['sources'])) {
            throw new RuntimeException('Sources não encontrado na resposta');
        }

        if (isset($response['sources'][0]['url'])) {
            return $response['sources'][0]['url'];
        }

        if (isset($response['sources'][1]['url'])) {
            return $response['sources'][1]['url'];
        }

        throw new RuntimeException('URL do vídeo não encontrada na resposta');
    }

    public function processVideoRequest(): string {
        if (!isset($_GET['id']) || !isset($_GET['lat']) || !isset($_GET['long'])) {
            throw new RuntimeException('Parâmetros obrigatórios não fornecidos');
        }

        try {
            $quality = $_GET['quality'] ?? 'HD';
            $qualityValue = $this->qualityMap[$quality] ?? 'max';

            $postData = [
                "video_id" => $_GET['id'],
                "player_type" => "android_native",
                "player_version" => "36.0.0",
                "quality" => $qualityValue,
                "content_protection" => "widevine",
                "tz" => "-03:00",
                "ts" => time(),
                "lat" => $_GET['lat'],
                "long" => $_GET['long'],
                "vsid" => $this->vsid,
                "flt" => true
            ];

            $response = $this->makeCurlRequest($postData);
            return $this->getVideoUrl($response);
        } catch (Exception $e) {
            throw new RuntimeException($e->getMessage());
        }
    }
}

try {
    $manager = new VideoSessionManager();
    $url = $manager->processVideoRequest();
    
    //  redireciona
    header('Location: ' . $url);
    exit;
	
	
} catch (Exception $e) {
    http_response_code(500);
    header('Content-Type: application/json');
    echo json_encode([
        'error' => true,
        'message' => $e->getMessage()
    ]);
    exit;
}